from  setuptools import setup

setup(name='zaagpro',version='1.0',description='to say the hello world',url='',author_email='rahulkrishnanfs@gmail.com',licence='MIT',packages=['zaagpro'],zip_safe=False)
